<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>View Lyrics</source>
        <translation>Pokaż tekst piosenki</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="31"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="36"/>
        <source>Lyrics</source>
        <translation>Tekst piosenki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="36"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="68"/>
        <source>About Lyrics Plugin</source>
        <translation>O wtyczce Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="69"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Wtyczka Teksty piosenek dla Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="70"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Ta wtyczka ściąga teksty piosenek z LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="71"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="72"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation>Na podstawie skryptu Ultimate Lyrics autorstwa Vladimira Brkica &lt;vladimir_brkic@yahoo.com&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsSettingsDialog</name>
    <message>
        <location filename="../lyricssettingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation>Ustawienia wtyczki Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricssettingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation>Dostawcy tekstów piosenek:</translation>
    </message>
</context>
<context>
    <name>LyricsWidget</name>
    <message>
        <location filename="../lyricswidget.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Wtyczka Teksty piosenek</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="31"/>
        <source>Provider:</source>
        <translation>Dostawca:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="115"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="132"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="142"/>
        <source>Artist:</source>
        <translation>Artysta:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="159"/>
        <source>Track:</source>
        <translation>Ścieżka:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.ui" line="171"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="148"/>
        <location filename="../lyricswidget.cpp" line="234"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="159"/>
        <source>Not found</source>
        <translation>Nie znaleziono</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="169"/>
        <source>Error: %1 - %2</source>
        <translation>Błąd: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="182"/>
        <source>Receiving</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="236"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../lyricswidget.cpp" line="257"/>
        <source>Cache</source>
        <translation>Pamięć podręczna</translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="116"/>
        <source>%1 (line: %2)</source>
        <translation>%1 (wiersz: %2)</translation>
    </message>
</context>
</TS>
